pub enum ReducerMode {
Streaming(StreamingReducerOpts),
Once(usize),
}Expand description
The mode in which a reducer operates.
Variants
Streaming(StreamingReducerOpts)
Streaming mode: continuously reduce and emit updates based on buffer size/timeout.
Once(usize)
Once mode: accumulate exactly n values, emit a single reduced update, then tear down.
Implementations
Sourceimpl ReducerMode
impl ReducerMode
Sourcepub fn is_streaming(&self) -> bool
pub fn is_streaming(&self) -> bool
Returns true if this is a ReducerMode::Streaming, otherwise false
Sourcepub fn as_streaming_mut(&mut self) -> Option<&mut StreamingReducerOpts>
pub fn as_streaming_mut(&mut self) -> Option<&mut StreamingReducerOpts>
Optionally returns mutable references to the inner fields if this is a ReducerMode::Streaming, otherwise None
Sourcepub fn as_streaming(&self) -> Option<&StreamingReducerOpts>
pub fn as_streaming(&self) -> Option<&StreamingReducerOpts>
Optionally returns references to the inner fields if this is a ReducerMode::Streaming, otherwise None
Sourcepub fn into_streaming(self) -> Result<StreamingReducerOpts, Self>
pub fn into_streaming(self) -> Result<StreamingReducerOpts, Self>
Returns the inner fields if this is a ReducerMode::Streaming, otherwise returns back the enum in the Err case of the result
Sourcepub fn as_once_mut(&mut self) -> Option<&mut usize>
pub fn as_once_mut(&mut self) -> Option<&mut usize>
Optionally returns mutable references to the inner fields if this is a ReducerMode::Once, otherwise None